@@ -42,6 +42,8 @@ def get_time(data=None, template='%d.%m.%Y %H:%M:%S', tz=0):
 
     if data is None:
         data = time.time()
+    if isinstance(data, str):
+        return data
 
     # TODO: smart TZ
 
@@ -50,6 +52,25 @@ def get_time(data=None, template='%d.%m.%Y %H:%M:%S', tz=0):
 
     return time.strftime(template, time.gmtime(data + tz * 3600))
 
+def decode_time(data=None, template='%d.%m.%Y %H:%M:%S', tz=0):
+    """ Get timestamp from time """
+
+    if not data:
+        return None
+    if isinstance(data, int):
+        return data
+
+    try:
+        data = datetime.datetime.strptime(data, template)
+    except ValueError:
+        return None
+
+    data = data.replace(
+        tzinfo=datetime.timezone(datetime.timedelta(hours=tz))
+    )
+
+    return int(data.timestamp())
+
 # pylint: disable=too-many-branches,too-many-statements
 def parse_time(data: str, tz=0):
     """ Parse time """
@@ -163,9 +184,9 @@ def format_delta(sec, short=False, locale='ru'):
                 delta += "d"
             else:
                 if time_def == 1:
-                    delta += f" day"
+                    delta += " day"
                 else:
-                    delta += f" days"
+                    delta += " days"
 
     elif abs(sec) >= 10800: # 3 hours
         time_def = round(sec / (60 * 60))
@@ -181,9 +202,9 @@ def format_delta(sec, short=False, locale='ru'):
                 delta += "h"
             else:
                 if time_def == 1:
-                    delta += f" hour"
+                    delta += " hour"
                 else:
-                    delta += f" hours"
+                    delta += " hours"
 
     elif abs(sec) > 180: # 3 min
         time_def = round(sec / 60)
@@ -199,9 +220,9 @@ def format_delta(sec, short=False, locale='ru'):
                 delta += "min"
             else:
                 if time_def == 1:
-                    delta += f" minute"
+                    delta += " minute"
                 else:
-                    delta += f" minutes"
+                    delta += " minutes"
 
     else:
         time_def = int(sec)
